@@ -59,8 +59,8 @@ Exif::SearchDialog::SearchDialog( QWidget* parent )
     gridLayout->setSpacing( 6 );
     hlay->addLayout( gridLayout );
     hlay->addStretch( 1 );
-    _apertureValue = makeApertureOrFNumber( i18n( "Aperture Value" ), QString::fromLatin1( "Exif_Photo_ApertureValue" ), gridLayout, 0 );
-    _fNumber = makeApertureOrFNumber( i18n( "F Number" ), QString::fromLatin1( "Exif_Photo_FNumber" ), gridLayout, 1 );
+    m_apertureValue = makeApertureOrFNumber( i18n( "Aperture Value" ), QString::fromLatin1( "Exif_Photo_ApertureValue" ), gridLayout, 0 );
+    m_fNumber = makeApertureOrFNumber( i18n( "F Number" ), QString::fromLatin1( "Exif_Photo_FNumber" ), gridLayout, 1 );
 
     hlay->addSpacing(30);
 
@@ -73,26 +73,26 @@ Exif::SearchDialog::SearchDialog( QWidget* parent )
     QLabel* label = new QLabel( i18n( "Focal Length" ) );
     focalLayout->addWidget(label);
 
-    _fromFocalLength = new QSpinBox;
-    focalLayout->addWidget(_fromFocalLength);
-    _fromFocalLength->setRange( 0, 10000 );
-    _fromFocalLength->setSingleStep( 10 );
+    m_fromFocalLength = new QSpinBox;
+    focalLayout->addWidget(m_fromFocalLength);
+    m_fromFocalLength->setRange( 0, 10000 );
+    m_fromFocalLength->setSingleStep( 10 );
 
     label = new QLabel( i18nc("As in 'A range from x to y'","to"));
     focalLayout->addWidget(label);
 
-    _toFocalLength = new QSpinBox;
-    focalLayout->addWidget(_toFocalLength);
-    _toFocalLength->setRange( 0, 10000 );
-    _toFocalLength->setSingleStep( 10 );
+    m_toFocalLength = new QSpinBox;
+    focalLayout->addWidget(m_toFocalLength);
+    m_toFocalLength->setRange( 0, 10000 );
+    m_toFocalLength->setSingleStep( 10 );
 
-    _toFocalLength->setValue( 10000 );
+    m_toFocalLength->setValue( 10000 );
     QString suffix = i18nc( "This is millimeter for focal length, like 35mm", "mm" );
-    _fromFocalLength->setSuffix( suffix );
-    _toFocalLength->setSuffix( suffix );
+    m_fromFocalLength->setSuffix( suffix );
+    m_toFocalLength->setSuffix( suffix );
 
-    connect( _fromFocalLength, SIGNAL(valueChanged(int)), this, SLOT(fromFocalLengthChanged(int)) );
-    connect( _toFocalLength, SIGNAL(valueChanged(int)), this, SLOT(toFocalLengthChanged(int)) );
+    connect( m_fromFocalLength, SIGNAL(valueChanged(int)), this, SLOT(fromFocalLengthChanged(int)) );
+    connect( m_toFocalLength, SIGNAL(valueChanged(int)), this, SLOT(toFocalLengthChanged(int)) );
 
     // exposure program and Metring mode
     hlay = new QHBoxLayout;
@@ -134,7 +134,7 @@ void Exif::SearchDialog::makeISO( QGridLayout* layout )
          << Exif::RangeWidget::Value( 25600, QString::fromLatin1("25600") )
          << Exif::RangeWidget::Value( 51200, QString::fromLatin1("51200") );
 
-    _iso = new RangeWidget( i18n("Iso setting" ), QString::fromLatin1( "Exif_Photo_ISOSpeedRatings" ), list, layout, 0 );
+    m_iso = new RangeWidget( i18n("Iso setting" ), QString::fromLatin1( "Exif_Photo_ISOSpeedRatings" ), list, layout, 0 );
 }
 
 void Exif::SearchDialog::makeExposureTime( QGridLayout* layout )
@@ -195,7 +195,7 @@ void Exif::SearchDialog::makeExposureTime( QGridLayout* layout )
         << Exif::RangeWidget::Value( 25, QString::fromLatin1( "25 %1").arg(secs ) )
         << Exif::RangeWidget::Value( 30, QString::fromLatin1( "30 %1").arg(secs ) );
 
-    _exposureTime = new RangeWidget( i18n("Exposure time" ), QString::fromLatin1( "Exif_Photo_ExposureTime" ), list, layout, 1 );
+    m_exposureTime = new RangeWidget( i18n("Exposure time" ), QString::fromLatin1( "Exif_Photo_ExposureTime" ), list, layout, 1 );
 }
 
 RangeWidget* Exif::SearchDialog::makeApertureOrFNumber( const QString& text, const QString& key, QGridLayout* layout, int row )
@@ -248,15 +248,15 @@ QWidget* Exif::SearchDialog::makeExposureProgram( QWidget* parent )
     QGroupBox* box = new QGroupBox( i18n( "Exposure Program" ), parent );
     QVBoxLayout* layout = new QVBoxLayout(box);
 
-    addSetting( _exposureProgram, "Not defined", 0 );
-    addSetting( _exposureProgram, "Manual", 1 );
-    addSetting( _exposureProgram, "Normal program", 2 );
-    addSetting( _exposureProgram, "Aperture priority", 3 );
-    addSetting( _exposureProgram, "Shutter priority", 4 );
-    addSetting( _exposureProgram, "Creative program (biased toward depth of field)", 5 );
-    addSetting( _exposureProgram, "Action program (biased toward fast shutter speed)", 6 );
-    addSetting( _exposureProgram, "Portrait mode (for closeup photos with the background out of focus)", 7 );
-    addSetting( _exposureProgram, "Landscape mode (for landscape photos with the background in focus)", 8 );
+    addSetting( m_exposureProgram, "Not defined", 0 );
+    addSetting( m_exposureProgram, "Manual", 1 );
+    addSetting( m_exposureProgram, "Normal program", 2 );
+    addSetting( m_exposureProgram, "Aperture priority", 3 );
+    addSetting( m_exposureProgram, "Shutter priority", 4 );
+    addSetting( m_exposureProgram, "Creative program (biased toward depth of field)", 5 );
+    addSetting( m_exposureProgram, "Action program (biased toward fast shutter speed)", 6 );
+    addSetting( m_exposureProgram, "Portrait mode (for closeup photos with the background out of focus)", 7 );
+    addSetting( m_exposureProgram, "Landscape mode (for landscape photos with the background in focus)", 8 );
     return box;
 }
 
@@ -265,10 +265,10 @@ QWidget* Exif::SearchDialog::makeOrientation( QWidget* parent )
     QGroupBox* box = new QGroupBox( i18n( "Orientation" ), parent );
     QVBoxLayout* layout = new QVBoxLayout(box);
 
-    addSetting( _orientation, "Not rotated", 0);
-    addSetting( _orientation, "Rotated counterclockwise", 6 );
-    addSetting( _orientation, "Rotated clockwise", 8 );
-    addSetting( _orientation, "Rotated 180 degrees", 3 );
+    addSetting( m_orientation, "Not rotated", 0);
+    addSetting( m_orientation, "Rotated counterclockwise", 6 );
+    addSetting( m_orientation, "Rotated clockwise", 8 );
+    addSetting( m_orientation, "Rotated 180 degrees", 3 );
     return box;
 }
 
@@ -277,14 +277,14 @@ QWidget* Exif::SearchDialog::makeMeteringMode( QWidget* parent )
     QGroupBox* box = new QGroupBox( i18n( "Metering Mode" ), parent );
     QVBoxLayout* layout = new QVBoxLayout(box);
 
-    addSetting( _meteringMode, "Unknown", 0 );
-    addSetting( _meteringMode, "Average", 1 );
-    addSetting( _meteringMode, "CenterWeightedAverage", 2 );
-    addSetting( _meteringMode, "Spot", 3 );
-    addSetting( _meteringMode, "MultiSpot", 4 );
-    addSetting( _meteringMode, "Pattern", 5 );
-    addSetting( _meteringMode, "Partial", 6 );
-    addSetting( _meteringMode, "Other", 255 );
+    addSetting( m_meteringMode, "Unknown", 0 );
+    addSetting( m_meteringMode, "Average", 1 );
+    addSetting( m_meteringMode, "CenterWeightedAverage", 2 );
+    addSetting( m_meteringMode, "Spot", 3 );
+    addSetting( m_meteringMode, "MultiSpot", 4 );
+    addSetting( m_meteringMode, "Pattern", 5 );
+    addSetting( m_meteringMode, "Partial", 6 );
+    addSetting( m_meteringMode, "Other", 255 );
     return box;
 }
 
@@ -293,9 +293,9 @@ QWidget* Exif::SearchDialog::makeContrast( QWidget* parent )
     QGroupBox* box = new QGroupBox( i18n( "Contrast" ), parent );
     QVBoxLayout* layout = new QVBoxLayout(box);
 
-    addSetting( _contrast, "Normal", 0 );
-    addSetting( _contrast, "Soft", 1 );
-    addSetting( _contrast, "Hard", 2 );
+    addSetting( m_contrast, "Normal", 0 );
+    addSetting( m_contrast, "Soft", 1 );
+    addSetting( m_contrast, "Hard", 2 );
     return box;
 }
 
@@ -304,9 +304,9 @@ QWidget* Exif::SearchDialog::makeSharpness( QWidget* parent )
     QGroupBox* box = new QGroupBox( i18n( "Sharpness" ), parent );
     QVBoxLayout* layout = new QVBoxLayout(box);
 
-    addSetting( _sharpness, "Normal", 0 );
-    addSetting( _sharpness, "Soft", 1 );
-    addSetting( _sharpness, "Hard", 2 );
+    addSetting( m_sharpness, "Normal", 0 );
+    addSetting( m_sharpness, "Soft", 1 );
+    addSetting( m_sharpness, "Hard", 2 );
     return box;
 }
 
@@ -315,9 +315,9 @@ QWidget* Exif::SearchDialog::makeSaturation( QWidget* parent )
     QGroupBox* box = new QGroupBox( i18n( "Saturation" ), parent );
     QVBoxLayout* layout = new QVBoxLayout(box);
 
-    addSetting( _saturation, "Normal", 0 );
-    addSetting( _saturation, "Low", 1 );
-    addSetting( _saturation, "High", 2 );
+    addSetting( m_saturation, "Normal", 0 );
+    addSetting( m_saturation, "Low", 1 );
+    addSetting( m_saturation, "High", 2 );
     return box;
 }
 
@@ -329,22 +329,22 @@ QStringList Exif::SearchDialog::availableCameras()
 Exif::SearchInfo Exif::SearchDialog::info()
 {
     Exif::SearchInfo result;
-    result.addSearchKey( QString::fromLatin1( "Exif_Photo_MeteringMode" ), _meteringMode.selected() );
-    result.addSearchKey( QString::fromLatin1( "Exif_Photo_ExposureProgram" ), _exposureProgram.selected() );
-    result.addSearchKey( QString::fromLatin1( "Exif_Image_Orientation" ), _orientation.selected() );
-    result.addSearchKey( QString::fromLatin1( "Exif_Photo_MeteringMode" ), _meteringMode.selected() );
-    result.addSearchKey( QString::fromLatin1( "Exif_Photo_Contrast" ), _contrast.selected() );
-    result.addSearchKey( QString::fromLatin1( "Exif_Photo_Sharpness" ), _sharpness.selected() );
-    result.addSearchKey( QString::fromLatin1( "Exif_Photo_Saturation" ), _saturation.selected() );
-    result.addCamera( _cameras.selected() );
-    result.addRangeKey( _iso->range() );
-    result.addRangeKey( _exposureTime->range() );
-    result.addRangeKey( _apertureValue->range() );
-    result.addRangeKey( _fNumber->range() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Photo_MeteringMode" ), m_meteringMode.selected() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Photo_ExposureProgram" ), m_exposureProgram.selected() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Image_Orientation" ), m_orientation.selected() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Photo_MeteringMode" ), m_meteringMode.selected() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Photo_Contrast" ), m_contrast.selected() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Photo_Sharpness" ), m_sharpness.selected() );
+    result.addSearchKey( QString::fromLatin1( "Exif_Photo_Saturation" ), m_saturation.selected() );
+    result.addCamera( m_cameras.selected() );
+    result.addRangeKey( m_iso->range() );
+    result.addRangeKey( m_exposureTime->range() );
+    result.addRangeKey( m_apertureValue->range() );
+    result.addRangeKey( m_fNumber->range() );
 
     SearchInfo::Range focalRange( QString::fromLatin1( "Exif_Photo_FocalLength" ) );
-    focalRange.min = _fromFocalLength->value();
-    focalRange.max = _toFocalLength->value();
+    focalRange.min = m_fromFocalLength->value();
+    focalRange.max = m_toFocalLength->value();
     result.addRangeKey( focalRange );
     return result;
 }
@@ -365,7 +365,7 @@ QWidget* Exif::SearchDialog::makeCamera()
     for( QList< QPair<QString,QString> >::ConstIterator cameraIt = cameras.constBegin(); cameraIt != cameras.constEnd(); ++cameraIt ) {
         QCheckBox* cb = new QCheckBox( QString::fromLatin1( "%1 - %2" ).arg( (*cameraIt).first.trimmed() ).arg( (*cameraIt).second.trimmed() ) );
         layout->addWidget( cb );
-        _cameras.append( Setting< QPair<QString,QString> >( cb, *cameraIt ) );
+        m_cameras.append( Setting< QPair<QString,QString> >( cb, *cameraIt ) );
     }
 
     if ( cameras.isEmpty() ) {
@@ -378,14 +378,14 @@ QWidget* Exif::SearchDialog::makeCamera()
 
 void Exif::SearchDialog::fromFocalLengthChanged( int val )
 {
-    if ( _toFocalLength->value() < val )
-        _toFocalLength->setValue( val );
+    if ( m_toFocalLength->value() < val )
+        m_toFocalLength->setValue( val );
 }
 
 void Exif::SearchDialog::toFocalLengthChanged( int val )
 {
-    if ( _fromFocalLength->value() > val )
-        _fromFocalLength->setValue( val );
+    if ( m_fromFocalLength->value() > val )
+        m_fromFocalLength->setValue( val );
 }
 
 
