@@ -40,47 +40,47 @@ Settings::FileVersionDetectionPage::FileVersionDetectionPage( QWidget* parent )
         QVBoxLayout* layout = new QVBoxLayout(generalBox);
 
         // Search for images on startup
-        _searchForImagesOnStart = new QCheckBox( i18n("Search for new images and videos on startup"), generalBox );
-        layout->addWidget(_searchForImagesOnStart);
+        m_searchForImagesOnStart = new QCheckBox( i18n("Search for new images and videos on startup"), generalBox );
+        layout->addWidget(m_searchForImagesOnStart);
 
-        _ignoreFileExtension = new QCheckBox( i18n("Ignore file extensions when searching for new images and videos"), generalBox);
-        layout->addWidget(_ignoreFileExtension);
+        m_ignoreFileExtension = new QCheckBox( i18n("Ignore file extensions when searching for new images and videos"), generalBox);
+        layout->addWidget(m_ignoreFileExtension);
 
-        _skipSymlinks = new QCheckBox( i18n("Skip symbolic links when searching for new images"), generalBox );
-        layout->addWidget(_skipSymlinks);
+        m_skipSymlinks = new QCheckBox( i18n("Skip symbolic links when searching for new images"), generalBox );
+        layout->addWidget(m_skipSymlinks);
 
-        _skipRawIfOtherMatches = new QCheckBox( i18n("Do not read RAW files if a matching JPEG/TIFF file exists"), generalBox );
-        layout->addWidget(_skipRawIfOtherMatches);
+        m_skipRawIfOtherMatches = new QCheckBox( i18n("Do not read RAW files if a matching JPEG/TIFF file exists"), generalBox );
+        layout->addWidget(m_skipRawIfOtherMatches);
 
         // Exclude directories from search
         QLabel* excludeDirectoriesLabel = new QLabel( i18n("Directories to exclude from new file search:" ), generalBox );
         layout->addWidget(excludeDirectoriesLabel);
 
-        _excludeDirectories = new KLineEdit( generalBox );
-        layout->addWidget(_excludeDirectories);
-        excludeDirectoriesLabel->setBuddy( _excludeDirectories );
+        m_excludeDirectories = new KLineEdit( generalBox );
+        layout->addWidget(m_excludeDirectories);
+        excludeDirectoriesLabel->setBuddy( m_excludeDirectories );
 
         txt = i18n( "<p>KPhotoAlbum is capable of searching for new images and videos when started, this does, "
                     "however, take some time, so instead you may wish to manually tell KPhotoAlbum to search for new images "
                     "using <b>Maintenance->Rescan for new images</b></p>");
-        _searchForImagesOnStart->setWhatsThis( txt );
+        m_searchForImagesOnStart->setWhatsThis( txt );
 
         txt = i18n( "<p>KPhotoAlbum will normally search new images and videos by their file extension. "
                     "If this option is set, <em>all</em> files neither in the database nor in the block list "
                     "will be checked by their Mime type, regardless of their extension. This will take "
                     "significantly longer than finding files by extension!</p>");
-        _ignoreFileExtension->setWhatsThis( txt );
+        m_ignoreFileExtension->setWhatsThis( txt );
 
         txt = i18n( "<p>KPhotoAlbum attempts to read all image files whether actual files or symbolic links. If you "
                     "wish to ignore symbolic links, check this option. This is useful if for some reason you have e.g. "
                     "both the original files and symbolic links to these files within your image directory.</p>");
-        _skipSymlinks->setWhatsThis( txt );
+        m_skipSymlinks->setWhatsThis( txt );
 
         txt = i18n( "<p>KPhotoAlbum is capable of reading certain kinds of RAW images. "
                     "Some cameras store both a RAW image and a matching JPEG or TIFF image. "
                     "This causes duplicate images to be stored in KPhotoAlbum, which may be undesirable. "
                     "If this option is checked, KPhotoAlbum will not read RAW files for which matching image files also exist.</p>");
-        _skipRawIfOtherMatches->setWhatsThis( txt );
+        m_skipRawIfOtherMatches->setWhatsThis( txt );
 
         txt = i18n( "<p>Directories defined here (separated by comma <tt>,</tt>) are "
                     "skipped when searching for new photos. Thumbnail directories of different "
@@ -95,33 +95,33 @@ Settings::FileVersionDetectionPage::FileVersionDetectionPage( QWidget* parent )
         topLayout->addWidget( modifiedBox );
         QVBoxLayout* layout = new QVBoxLayout(modifiedBox);
 
-        _detectModifiedFiles = new QCheckBox(i18n("Try to detect multiple versions of files"), modifiedBox);
-        layout->addWidget(_detectModifiedFiles);
+        m_detectModifiedFiles = new QCheckBox(i18n("Try to detect multiple versions of files"), modifiedBox);
+        layout->addWidget(m_detectModifiedFiles);
 
         QLabel* modifiedFileComponentLabel = new QLabel( i18n("File versions search regexp:" ), modifiedBox );
         layout->addWidget(modifiedFileComponentLabel);
 
-        _modifiedFileComponent = new KLineEdit(modifiedBox);
-        layout->addWidget(_modifiedFileComponent);
+        m_modifiedFileComponent = new KLineEdit(modifiedBox);
+        layout->addWidget(m_modifiedFileComponent);
 
         QLabel* originalFileComponentLabel = new QLabel( i18n("Original file replacement text:" ), modifiedBox );
         layout->addWidget(originalFileComponentLabel);
 
-        _originalFileComponent = new KLineEdit(modifiedBox);
-        layout->addWidget(_originalFileComponent);
+        m_originalFileComponent = new KLineEdit(modifiedBox);
+        layout->addWidget(m_originalFileComponent);
 
-        _moveOriginalContents = new QCheckBox(i18n("Move meta-data (i.e. delete tags from the original):"), modifiedBox);
-        layout->addWidget(_moveOriginalContents);
+        m_moveOriginalContents = new QCheckBox(i18n("Move meta-data (i.e. delete tags from the original):"), modifiedBox);
+        layout->addWidget(m_moveOriginalContents);
 
-        _autoStackNewFiles = new QCheckBox(i18n("Automatically stack new versions of images"), modifiedBox);
-        layout->addWidget(_autoStackNewFiles);
+        m_autoStackNewFiles = new QCheckBox(i18n("Automatically stack new versions of images"), modifiedBox);
+        layout->addWidget(m_autoStackNewFiles);
 
         txt = i18n( "<p>When KPhotoAlbum searches for new files and finds a file that matches the "
                     "<i>modified file search regexp</i> it is assumed that an original version of "
                     "the image may exist. The regexp pattern will be replaced with the <i>original "
                     "file replacement text</i> and if that file exists, all associated metadata (category "
                     "information, ratings, etc) will be copied or moved from the original file to the new one.</p>");
-        _detectModifiedFiles->setWhatsThis( txt );
+        m_detectModifiedFiles->setWhatsThis( txt );
 
         txt = i18n( "<p>A perl regular expression that should match a modified file. "
                     "<ul><li>A dot matches a single character (<tt>\\.</tt> matches a dot)</li> "
@@ -131,22 +131,22 @@ Settings::FileVersionDetectionPage::FileVersionDetectionPage( QWidget* parent )
                     "  <li>You can group parts of the expression using parenthesis.</li> "
                     "</ul>Example: <tt>-modified\\.(jpg|tiff)</tt> </p>");
         modifiedFileComponentLabel->setWhatsThis( txt );
-        _modifiedFileComponent->setWhatsThis( txt );
+        m_modifiedFileComponent->setWhatsThis( txt );
 
         txt = i18n( "<p>A string that is used to replace the match from the <i>File versions search regexp</i>. "
                     "This can be a semicolon (<tt>;</tt>) separated list. Each string is used to replace the match "
                     "in the new file's name until an original file is found or we run out of options.</p>");
         originalFileComponentLabel->setWhatsThis( txt );
-        _originalFileComponent->setWhatsThis( txt );
+        m_originalFileComponent->setWhatsThis( txt );
 
         txt = i18n( "<p>The tagging is moved from the original file to the new file. This way "
                     "only the latest version of an image is tagged.</p>" );
-        _moveOriginalContents->setWhatsThis( txt );
+        m_moveOriginalContents->setWhatsThis( txt );
 
         txt = i18n( "<p>If this option is set, new versions of an image are automatically stacked "
                     "and placed to the top of the stack. This way the new image is shown when the "
                     "stack is in collapsed state - the default state in KPhotoAlbum.</p>" );
-        _autoStackNewFiles->setWhatsThis( txt );
+        m_autoStackNewFiles->setWhatsThis( txt );
     }
 
     // Copy File Support
@@ -158,54 +158,70 @@ Settings::FileVersionDetectionPage::FileVersionDetectionPage( QWidget* parent )
         QLabel* copyFileComponentLabel = new QLabel( i18n("Copy file search regexp:" ), copyBox );
         layout->addWidget(copyFileComponentLabel);
 
-        _copyFileComponent = new KLineEdit(copyBox);
-        layout->addWidget(_copyFileComponent);
+        m_copyFileComponent = new KLineEdit(copyBox);
+        layout->addWidget(m_copyFileComponent);
 
         QLabel* copyFileReplacementComponentLabel = new QLabel( i18n("Copy file replacement text:" ), copyBox );
         layout->addWidget(copyFileReplacementComponentLabel);
 
-        _copyFileReplacementComponent = new KLineEdit(copyBox);
-        layout->addWidget(_copyFileReplacementComponent);
+        m_copyFileReplacementComponent = new KLineEdit(copyBox);
+        layout->addWidget(m_copyFileReplacementComponent);
 
         txt = i18n("<p>KPhotoAlbum can make a copy of an image before opening it with an external application. This configuration defines how the new file is named.</p>"
                    "<p>The regular expression defines the part of the original file name that is replaced with the <i>replacement text</i>. "
                    "E.g. regexp <i>\"\\.(jpg|png)\"</i> and replacement text <i>\"-mod.\\1\"</i> would copy test.jpg to test-mod.jpg and open the new file in selected application.</p>");
         copyFileComponentLabel->setWhatsThis( txt );
-        _copyFileComponent->setWhatsThis( txt );
+        m_copyFileComponent->setWhatsThis( txt );
         copyFileReplacementComponentLabel->setWhatsThis( txt );
-        _copyFileReplacementComponent->setWhatsThis( txt );
+        m_copyFileReplacementComponent->setWhatsThis( txt );
     }
 
 }
 
+Settings::FileVersionDetectionPage::~FileVersionDetectionPage()
+{
+    delete m_searchForImagesOnStart;
+    delete m_ignoreFileExtension;
+    delete m_skipSymlinks;
+    delete m_skipRawIfOtherMatches;
+    delete m_excludeDirectories;
+    delete m_detectModifiedFiles;
+    delete m_modifiedFileComponent;
+    delete m_originalFileComponent;
+    delete m_moveOriginalContents;
+    delete m_autoStackNewFiles;
+    delete m_copyFileComponent;
+    delete m_copyFileReplacementComponent;
+}
+
 void Settings::FileVersionDetectionPage::loadSettings( Settings::SettingsData* opt )
 {
-    _searchForImagesOnStart->setChecked( opt->searchForImagesOnStart() );
-    _ignoreFileExtension->setChecked( opt->ignoreFileExtension() );
-    _skipSymlinks->setChecked( opt->skipSymlinks() );
-    _skipRawIfOtherMatches->setChecked( opt->skipRawIfOtherMatches() );
-    _excludeDirectories->setText( opt->excludeDirectories() );
-    _detectModifiedFiles->setChecked( opt->detectModifiedFiles() );
-    _modifiedFileComponent->setText( opt->modifiedFileComponent() );
-    _originalFileComponent->setText( opt->originalFileComponent() );
-    _moveOriginalContents->setChecked( opt->moveOriginalContents() );
-    _autoStackNewFiles->setChecked( opt->autoStackNewFiles() );
-    _copyFileComponent->setText( opt->copyFileComponent() );
-    _copyFileReplacementComponent->setText( opt->copyFileReplacementComponent() );
+    m_searchForImagesOnStart->setChecked( opt->searchForImagesOnStart() );
+    m_ignoreFileExtension->setChecked( opt->ignoreFileExtension() );
+    m_skipSymlinks->setChecked( opt->skipSymlinks() );
+    m_skipRawIfOtherMatches->setChecked( opt->skipRawIfOtherMatches() );
+    m_excludeDirectories->setText( opt->excludeDirectories() );
+    m_detectModifiedFiles->setChecked( opt->detectModifiedFiles() );
+    m_modifiedFileComponent->setText( opt->modifiedFileComponent() );
+    m_originalFileComponent->setText( opt->originalFileComponent() );
+    m_moveOriginalContents->setChecked( opt->moveOriginalContents() );
+    m_autoStackNewFiles->setChecked( opt->autoStackNewFiles() );
+    m_copyFileComponent->setText( opt->copyFileComponent() );
+    m_copyFileReplacementComponent->setText( opt->copyFileReplacementComponent() );
 }
 
 void Settings::FileVersionDetectionPage::saveSettings( Settings::SettingsData* opt )
 {
-    opt->setSearchForImagesOnStart( _searchForImagesOnStart->isChecked() );
-    opt->setIgnoreFileExtension( _ignoreFileExtension->isChecked() );
-    opt->setSkipSymlinks( _skipSymlinks->isChecked() );
-    opt->setSkipRawIfOtherMatches( _skipRawIfOtherMatches->isChecked() );
-    opt->setExcludeDirectories( _excludeDirectories->text() );
-    opt->setDetectModifiedFiles( _detectModifiedFiles->isChecked() );
-    opt->setModifiedFileComponent( _modifiedFileComponent->text() );
-    opt->setOriginalFileComponent( _originalFileComponent->text() );
-    opt->setAutoStackNewFiles( _autoStackNewFiles->isChecked() );
-    opt->setCopyFileComponent( _copyFileComponent->text() );
-    opt->setCopyFileReplacementComponent( _copyFileReplacementComponent->text() );
+    opt->setSearchForImagesOnStart( m_searchForImagesOnStart->isChecked() );
+    opt->setIgnoreFileExtension( m_ignoreFileExtension->isChecked() );
+    opt->setSkipSymlinks( m_skipSymlinks->isChecked() );
+    opt->setSkipRawIfOtherMatches( m_skipRawIfOtherMatches->isChecked() );
+    opt->setExcludeDirectories( m_excludeDirectories->text() );
+    opt->setDetectModifiedFiles( m_detectModifiedFiles->isChecked() );
+    opt->setModifiedFileComponent( m_modifiedFileComponent->text() );
+    opt->setOriginalFileComponent( m_originalFileComponent->text() );
+    opt->setAutoStackNewFiles( m_autoStackNewFiles->isChecked() );
+    opt->setCopyFileComponent( m_copyFileComponent->text() );
+    opt->setCopyFileReplacementComponent( m_copyFileReplacementComponent->text() );
 }
 // vi:expandtab:tabstop=4 shiftwidth=4:
