@@ -22,6 +22,7 @@
 #include "DB/ImageInfoPtr.h"
 #include "DB/ImageInfo.h"
 #include <QSharedPointer>
+#include <QMap>
 #include "XmlReader.h"
 
 
@@ -35,10 +36,10 @@ class FileReader
 {
 
 public:
-    FileReader( Database* db ) : _db( db ), _nextStackId(1) {}
+    FileReader( Database* db ) : m_db( db ), m_nextStackId(1), m_newToOldName() {}
     void read( const QString& configFile );
     static QString unescape( const QString& );
-    DB::StackID nextStackId() const { return _nextStackId; };
+    DB::StackID nextStackId() const { return m_nextStackId; };
 
 protected:
     void readTopNodeInConfigDocument( const QString& configFile, QDomElement top, QDomElement* options, QDomElement* images,
@@ -55,16 +56,25 @@ protected:
     void checkIfImagesAreSorted();
     void checkIfAllImagesHasSizeAttributes();
 
+    /**
+     * Returns the category name, but converts outdated standard category names.
+     * Standard categories stored with their localized name (a flaw of older KPA versions)
+     * are corrected as well.
+     */
+    QString sanitizedCategoryName( const QString& category);
+
     // The parent widget information dialogs are displayed in.
     QWidget *messageParent();
 
 private:
-    Database* const _db;
-    int _fileVersion;
-    DB::StackID _nextStackId;
+    Database* const m_db;
+    int m_fileVersion;
+    DB::StackID m_nextStackId;
 
+    // internal mapping created by sanitizedCategoryName:
+    QMap<QString,QString> m_newToOldName;
     // During profilation I found that it was rather expensive to look this up over and over again (once for each image)
-    DB::CategoryPtr _folderCategory;
+    DB::CategoryPtr m_folderCategory;
 };
 
 }
